==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.md <==
# AmazonElasticContainerRegistryRegistry


```text
aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')
```



| Illustration | AmazonElasticContainerRegistryRegistry | AmazonElasticContainerRegistryRegistryCard | AmazonElasticContainerRegistryRegistryGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.png) | ![illustration for AmazonElasticContainerRegistryRegistry](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.Local.png) | ![illustration for AmazonElasticContainerRegistryRegistryCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistryCard.Local.png) | ![illustration for AmazonElasticContainerRegistryRegistryGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistryGroup.Local.png) |




## AmazonElasticContainerRegistryRegistry

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistry
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistry('AmazonElasticContainerRegistryRegistry', 'Amazon Elastic Container Registry Registry', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistry
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistry('AmazonElasticContainerRegistryRegistry', 'Amazon Elastic Container Registry Registry', 'an optional tech label')
@enduml
```

## AmazonElasticContainerRegistryRegistryCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryCard('AmazonElasticContainerRegistryRegistryCard', 'Amazon Elastic Container Registry Registry Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryCard('AmazonElasticContainerRegistryRegistryCard', 'Amazon Elastic Container Registry Registry Card', 'an optional description')
@enduml
```

## AmazonElasticContainerRegistryRegistryGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryGroup('AmazonElasticContainerRegistryRegistryGroup', 'Amazon Elastic Container Registry Registry Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryGroup('AmazonElasticContainerRegistryRegistryGroup', 'Amazon Elastic Container Registry Registry Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.md <==
# AmazonElasticContainerRegistryRegistry


```text
aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')
```



| Illustration | AmazonElasticContainerRegistryRegistry | AmazonElasticContainerRegistryRegistryCard | AmazonElasticContainerRegistryRegistryGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.png) | ![illustration for AmazonElasticContainerRegistryRegistry](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry.Local.png) | ![illustration for AmazonElasticContainerRegistryRegistryCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistryCard.Local.png) | ![illustration for AmazonElasticContainerRegistryRegistryGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistryGroup.Local.png) |




## AmazonElasticContainerRegistryRegistry

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistry
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistry('AmazonElasticContainerRegistryRegistry', 'Amazon Elastic Container Registry Registry', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistry
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistry('AmazonElasticContainerRegistryRegistry', 'Amazon Elastic Container Registry Registry', 'an optional tech label')
@enduml
```

## AmazonElasticContainerRegistryRegistryCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryCard('AmazonElasticContainerRegistryRegistryCard', 'Amazon Elastic Container Registry Registry Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryCard('AmazonElasticContainerRegistryRegistryCard', 'Amazon Elastic Container Registry Registry Card', 'an optional description')
@enduml
```

## AmazonElasticContainerRegistryRegistryGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryGroup('AmazonElasticContainerRegistryRegistryGroup', 'Amazon Elastic Container Registry Registry Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryRegistryGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerRegistryRegistry')

' renders the element
AmazonElasticContainerRegistryRegistryGroup('AmazonElasticContainerRegistryRegistryGroup', 'Amazon Elastic Container Registry Registry Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
